Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorMarkus Keller2013-08-16 16:29:53 +0000
committerMarkus Keller2013-08-16 16:29:53 +0000
commit319e132378b5c1c0aece8d1d96f3f91cd79e4d01 (patch)
treed909a8c123228f61369f174ba38eace5a005b61b /org.eclipse.jdt.annotation/src/org/eclipse/jdt
parentf6e41fcbae6b07a9efa1ca2e2b5d7b062827d264 (diff)
downloadeclipse.jdt.core-319e132378b5c1c0aece8d1d96f3f91cd79e4d01.tar.gz
eclipse.jdt.core-319e132378b5c1c0aece8d1d96f3f91cd79e4d01.tar.xz
eclipse.jdt.core-319e132378b5c1c0aece8d1d96f3f91cd79e4d01.zip
fixed Javadocs (@link cannot refer to a statically-imported field; <ol> cannot nest in <p>)
Diffstat (limited to 'org.eclipse.jdt.annotation/src/org/eclipse/jdt')
-rw-r--r--org.eclipse.jdt.annotation/src/org/eclipse/jdt/annotation/NonNull.java5
-rw-r--r--org.eclipse.jdt.annotation/src/org/eclipse/jdt/annotation/Nullable.java5
2 files changed, 6 insertions, 4 deletions
diff --git a/org.eclipse.jdt.annotation/src/org/eclipse/jdt/annotation/NonNull.java b/org.eclipse.jdt.annotation/src/org/eclipse/jdt/annotation/NonNull.java
index 4ed4d3bdbf..844f03afca 100644
--- a/org.eclipse.jdt.annotation/src/org/eclipse/jdt/annotation/NonNull.java
+++ b/org.eclipse.jdt.annotation/src/org/eclipse/jdt/annotation/NonNull.java
@@ -18,15 +18,17 @@ package org.eclipse.jdt.annotation;
import static java.lang.annotation.ElementType.TYPE_USE;
import java.lang.annotation.Documented;
+import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
/**
* Qualifier for a reference type in a {@link TYPE_USE} position:
* The type that has this annotation is intended to not include the value <code>null</code>.
* <p>
* If annotation based null analysis is enabled using this annotation has two consequences:
+ * </p>
* <ol>
* <li>Dereferencing an expression of this type is safe, i.e., no <code>NullPointerException</code> can occur at runtime.</li>
* <li>An attempt to bind a <code>null</code> value to an entity (field, local variable, method parameter or method return value)
@@ -41,7 +43,6 @@ import java.lang.annotation.Target;
* <li>Nullness cannot be determined, because other program elements are involved for which
* null annotations are lacking.</li>
* </ol>
- * </p>
* @since 1.0
*/
@Documented
@@ -18,15 +18,17 @@ package org.eclipse.jdt.annotation;
import java.lang.annotation.Target;
/**
- * Qualifier for a reference type in a {@link TYPE_USE} position:
+ * Qualifier for a reference type in a {@link ElementType#TYPE_USE TYPE_USE} position:
* The type that has this annotation is intended to not include the value <code>null</code>.
* <p>
diff --git a/org.eclipse.jdt.annotation/src/org/eclipse/jdt/annotation/Nullable.java b/org.eclipse.jdt.annotation/src/org/eclipse/jdt/annotation/Nullable.java
index 1929b0768e..b7dc856f2f 100644
--- a/org.eclipse.jdt.annotation/src/org/eclipse/jdt/annotation/Nullable.java
+++ b/org.eclipse.jdt.annotation/src/org/eclipse/jdt/annotation/Nullable.java
@@ -18,21 +18,22 @@ package org.eclipse.jdt.annotation;
import static java.lang.annotation.ElementType.TYPE_USE;
import java.lang.annotation.Documented;
+import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
/**
* Qualifier for a reference type in a {@link TYPE_USE} position:
* The type that has this annotation explicitly includes the value <code>null</code>.
* <p>
* If annotation based null analysis is enabled using this annotation has two consequences:
+ * </p>
* <ol>
* <li>Binding a <code>null</code> value to an entity (field, local variable, method parameter or method return value)
* of this type is legal.</li>
* <li>Dereferencing an expression of this type is unsafe, i.e., a <code>NullPointerException</code> can occur at runtime.</li>
* </ol>
- * </p>
* @since 1.0
*/
@Documented

Back to the top
@@ -18,21 +18,22 @@ package org.eclipse.jdt.annotation;
import java.lang.annotation.Target;
/**
- * Qualifier for a reference type in a {@link TYPE_USE} position:
+ * Qualifier for a reference type in a {@link ElementType#TYPE_USE TYPE_USE} position:
* The type that has this annotation explicitly includes the value <code>null</code>.
* <p>